@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2022-11-25
+# Release 2022-12-05
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.6.3
+MAKERESOLVEDEB_VERSION=1.6.4
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -521,6 +521,8 @@ installer_extract_native() {
     link_object ${UNPACK_DIR} ./squashfs-root
     EXTRACT_OUT=$(./${INSTALLER_ARCHIVE} --appimage-extract 2>&1)
     rm -f ./squashfs-root
+    find ${UNPACK_DIR} -exec chmod a+r {} \;
+    find ${UNPACK_DIR} -type d -exec chmod a+x {} \;
     NUMEXTRACT=$(echo "${EXTRACT_OUT}" | grep "^squashfs-root/" -c)
     echo "Found ${NUMEXTRACT} objects"
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
